.. _acme.run_mc:

########
acme.run
########

This is a tutorial Model Component which is a partial implementation of the :ref:`acme-tutorial`.
Generally, this MC helps organize all components of the ACME network into an easy-to-run command.


**Attribute Provides:**
    * ``acme_run``

**Attribute Depends:**
    * ``acme_topology``
    * ``hostnames``

